==> apache-cxf-3.2.4-src.zip: apache-cxf-3.2.4-src/rt/frontend/jaxrs/src/test/java/org/apache/cxf/jaxrs/impl/SecurityContextImplTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.jaxrs.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;

import org.apache.cxf.message.Message;
import org.apache.cxf.message.MessageImpl;

import org.junit.Assert;
import org.junit.Test;

public class SecurityContextImplTest extends Assert {

    @Test
    public void testAuthenticationScheme() {
        Message m = new MessageImpl();
        Map<String, List<String>> requestHeaders
            = new TreeMap<String, List<String>>(String.CASE_INSENSITIVE_ORDER);
        List<String> values = new ArrayList<>();
        values.add("Digest realm=\"custom\"");
        requestHeaders.put("Authorization", values);
        m.put(Message.PROTOCOL_HEADERS, requestHeaders);
        String scheme = new SecurityContextImpl(m).getAuthenticationScheme();
        assertEquals("Digest", scheme);
    }
}

==> apache-cxf-3.6.6-src.zip: apache-cxf-3.6.6-src/rt/frontend/jaxrs/src/test/java/org/apache/cxf/jaxrs/impl/SecurityContextImplTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.jaxrs.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;

import org.apache.cxf.message.Message;
import org.apache.cxf.message.MessageImpl;

import org.junit.Test;

import static org.junit.Assert.assertEquals;

public class SecurityContextImplTest {

    @Test
    public void testAuthenticationScheme() {
        Message m = new MessageImpl();
        Map<String, List<String>> requestHeaders
            = new TreeMap<>(String.CASE_INSENSITIVE_ORDER);
        List<String> values = new ArrayList<>();
        values.add("Digest realm=\"custom\"");
        requestHeaders.put("Authorization", values);
        m.put(Message.PROTOCOL_HEADERS, requestHeaders);
        String scheme = new SecurityContextImpl(m).getAuthenticationScheme();
        assertEquals("Digest", scheme);
    }
}
